package com.ruoyi.model.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.AppletConfig;
import com.ruoyi.model.service.IAppletConfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 配置信息Controller
 * 
 * @author ruoyi
 * @date 2025-03-28
 */
@RestController
@RequestMapping("/model/AppletConfig")
public class AppletConfigController extends BaseController
{
    @Autowired
    private IAppletConfigService appletConfigService;

    /**
     * 查询配置信息列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletConfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(AppletConfig appletConfig)
    {
        startPage();
        List<AppletConfig> list = appletConfigService.selectAppletConfigList(appletConfig);
        return getDataTable(list);
    }

    /**
     * 导出配置信息列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletConfig:export')")
    @Log(title = "配置信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppletConfig appletConfig) throws IOException {
        List<AppletConfig> list = appletConfigService.selectAppletConfigList(appletConfig);
        ExcelUtil<AppletConfig> util = new ExcelUtil<AppletConfig>(AppletConfig.class);
        util.exportExcel(response, list, "配置信息数据");
    }

    /**
     * 获取配置信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppletConfig:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(appletConfigService.selectAppletConfigById(id));
    }

    /**
     * 新增配置信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppletConfig:add')")
    @Log(title = "配置信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppletConfig appletConfig)
    {
        return toAjax(appletConfigService.insertAppletConfig(appletConfig));
    }

    /**
     * 修改配置信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppletConfig:edit')")
    @Log(title = "配置信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppletConfig appletConfig)
    {
        return toAjax(appletConfigService.updateAppletConfig(appletConfig));
    }

    /**
     * 删除配置信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppletConfig:remove')")
    @Log(title = "配置信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(appletConfigService.deleteAppletConfigByIds(ids));
    }
}
